@@ -14,13 +14,14 @@ class FPFieldMixin():
     widget = FPFileWidget
     default_mimetypes = "*/*"
 
-    def initialize(self, apikey=None, mimetypes=None, services=None):
+    def initialize(self, apikey=None, mimetypes=None, services=None, additional_params=None):
         """
         Initializes the Filepicker field.
         Valid arguments:
         * apikey. This string is required if it isn't set as settings.FILEPICKER_API_KEY
         * mimetypes. Optional, the allowed mimetypes for files. Defaults to "*/*" (all files)
         * services. Optional, the allowed services to pull from.
+        * additional_params. Optional, additional parameters to be applied.
         """
 
         self.apikey = apikey or getattr(settings, 'FILEPICKER_API_KEY', None)
@@ -38,6 +39,7 @@ class FPFieldMixin():
                 self.mimetypes = str(self.mimetypes)
 
         self.services = services or getattr(settings, 'FILEPICKER_SERVICES', None)
+        self.additional_params = additional_params or getattr(settings, 'FILEPICKER_ADDITIONAL_PARAMS', None)
 
     def widget_attrs(self, widget):
         attrs = {
@@ -48,6 +50,9 @@ class FPFieldMixin():
         if self.services:
             attrs['data-fp-option-services'] = self.services
 
+        if self.additional_params:
+            attrs = dict(attrs.items() + self.additional_params.items())            
+
         return attrs
 
 
@@ -62,11 +67,13 @@ class FPUrlField(FPFieldMixin, forms.URLField):
         * apikey. This string is required if it isn't set as settings.FILEPICKER_API_KEY
         * mimetypes. Optional, the allowed mimetypes for files. Defaults to "*/*" (all files)
         * services. Optional, the allowed services to pull from.
+        * additional_params. Optional, additional parameters to be applied.
         """
         self.initialize(
             apikey=kwargs.pop('apikey', None),
             mimetypes=kwargs.pop('mimetypes', None),
             services=kwargs.pop('services', None),
+            additional_params=kwargs.pop('additional_params', None),
         )
         super(FPUrlField, self).__init__(*args, **kwargs)
 
@@ -79,11 +86,13 @@ class FPFileField(FPFieldMixin, forms.FileField):
         * apikey. This string is required if it isn't set as settings.FILEPICKER_API_KEY
         * mimetypes. Optional, the allowed mimetypes for files. Defaults to "*/*" (all files)
         * services. Optional, the allowed services to pull from.
+        * additional_params. Optional, additional parameters to be applied.
         """
         self.initialize(
             apikey=kwargs.pop('apikey', None),
             mimetypes=kwargs.pop('mimetypes', None),
             services=kwargs.pop('services', None),
+            additional_params=kwargs.pop('additional_params', None),
         )
         super(FPFileField, self).__init__(*args, **kwargs)
 
@@ -94,11 +103,15 @@ class FPFileField(FPFieldMixin, forms.FileField):
 
         url_fp = urllib2.urlopen(data)
 
+        name = "fp-file"
         disposition = url_fp.info().getheader('Content-Disposition')
         if disposition:
             name = disposition.rpartition("filename=")[2].strip('" ')
-        else:
-            name = "fp-file"
+
+        filename = url_fp.info().getheader('X-File-Name')
+        if filename:
+            name = filename
+
         size = long(url_fp.info().getheader('Content-Length', 0))
 
         fp = File(StringIO(url_fp.read()), name=name)
